@@ -23,19 +23,44 @@
 #       will be removed from Python at some later time. See:
 # https://docs.python.org/3/whatsnew/3.0.html#pep-3101-a-new-approach-to-string-formatting
 
+# NOTE: As mentioned by Klaus Höppner in "Typesetting tables with LaTeX", 'tabular*'
+#       style tables often (surprisingly) expand the space between columns.
+#       Switiching to 'tabular' style has the effect that the first column 
+#       varies in width, e.g. as "Wed" is wider than "Fri". 
+#       Also column 'v' in the Moon table, e.g. e.g. 6.9' versus 15.3'.
+#       Also column 'd' in the Moon table, e.g. e.g. -8.2' versus -13.9'.
+#       'Tabular' table style normally permits column width specification only for 
+#       (left-justified) paragraph column content (with the 'p' column specifier).
+#       A workaround is to use 'tabularx' table style and set the custom width
+#       to the maximum column width on variable column-width columns. However -
+#       \multicolumn entries must not cross any X-column, so it's out of question.
+#       A solution to extending the column specifiers on a 'tabular' table style
+#       with left-, center- and right-justified data plus a column width specifier
+#       is possible: https://de.wikibooks.org/wiki/LaTeX-W%C3%B6rterbuch:_tabular
+#       This works, but again increases the overall table width unnecessarily.
+#       Conclusion/Resolution:
+#       The following code now uses the 'tabular' table style without any
+#       column width specifiers - thus table widths vary slightly from page to page.
+
 # Standard library imports
 from math import copysign as copysign
 from math import degrees as degrees
+
 # Third party imports
 import ephem
+
 # Local application imports
 from pyalmanac.lib import alma_ephem as alma_ephem
 from pyalmanac.lib import config as config
 
 def planetstab(date):
     # generates a LaTeX table for the navigational plantets (traditional style)
+    # OLD: \begin{tabular*}{0.74\textwidth}[t]{@{\extracolsep{\fill}}|c|r|rr|rr|rr|rr|}
+    # OLD: \begin{tabular}[t]{|C{15pt}|r|rr|rr|rr|rr|}
+
     tab = r'''\noindent
-\begin{tabular*}{0.74\textwidth}[t]{@{\extracolsep{\fill}}|c|r|rr|rr|rr|rr|}
+\setlength{\tabcolsep}{5.8pt}  % default 6pt
+\begin{tabular}[t]{|c|r|rr|rr|rr|rr|}
 \multicolumn{1}{c}{\normalsize{}} & \multicolumn{1}{c}{\normalsize{Aries}} &  \multicolumn{2}{c}{\normalsize{Venus}}& \multicolumn{2}{c}{\normalsize{Mars}} & \multicolumn{2}{c}{\normalsize{Jupiter}} & \multicolumn{2}{c}{\normalsize{Saturn}}\\
 '''
     # note: 74% table width above removes "Overfull \hbox (1.65279pt too wide)"
@@ -113,16 +138,17 @@ def planetstab(date):
 '''.format(alma_ephem.ariestransit(date + n),vd[0],vd[1],vd[2],vd[3],vd[4],vd[5],vd[6],vd[7],vd[8],vd[9],vd[10],vd[11])
         n += 1
 
-    tab = tab + r'''\end{tabular*}
+    tab = tab + r'''\end{tabular}
 '''
     return tab
 
 
 def planetstabm(date):
     # generates a LaTeX table for the navigational plantets (modern style)
+
     tab = r'''\vspace{6Pt}\noindent
 \renewcommand{\arraystretch}{1.1}
-\setlength{\tabcolsep}{4pt}
+\setlength{\tabcolsep}{4pt}  % default 6pt
 \begin{tabular}[t]{crcrrcrrcrrcrr}
 \multicolumn{1}{c}{\normalsize{h}} & 
 \multicolumn{1}{c}{\normalsize{Aries}} & & 
@@ -226,17 +252,22 @@ def planetstabm(date):
 
 def starstab(date):
     # returns a table with ephemerieds for the navigational stars
-    out = r'''\begin{tabular*}{0.25\textwidth}[t]{@{\extracolsep{\fill}}|rrr|}
-\multicolumn{3}{c}{\normalsize{Stars}}\\
-'''
+    # OLD: \begin{tabular*}{0.25\textwidth}[t]{@{\extracolsep{\fill}}|rrr|}
+
     if config.tbls == "m":
-        out = out + r'''\hline
+        out = r'''\setlength{\tabcolsep}{4pt}  % default 6pt
+\begin{tabular}[t]{|rrr|}
+\multicolumn{3}{c}{\normalsize{Stars}}\\
+\hline
 & \multicolumn{1}{c}{\multirow{2}{*}{\textbf{SHA}}} 
 & \multicolumn{1}{c|}{\multirow{2}{*}{\textbf{Dec}}}\\
 & & \multicolumn{1}{c|}{} \\
 '''
     else:
-        out = out + r'''\hline
+        out = r'''\setlength{\tabcolsep}{5pt}  % default 6pt
+\begin{tabular}[t]{|rrr|}
+\multicolumn{3}{c}{\normalsize{Stars}}\\
+\hline
 \rule{0pt}{2.4ex} & \multicolumn{1}{c}{\textbf{SHA}} & \multicolumn{1}{c|}{\textbf{Dec}}\\
 \hline\rule{0pt}{2.6ex}\noindent
 '''
@@ -291,18 +322,26 @@ def starstab(date):
 '''
     out = out + hp
     
-    out = out + r'''\end{tabular*}'''
+    out = out + r'''\end{tabular}'''
     return out
 
 
 def sunmoontab(date):
     # generates LaTeX table for sun and moon (traditional style)
+    # OLD: \begin{tabular*}{0.54\textwidth}[t]{@{\extracolsep{\fill}}|c|rr|rrrrr|}
+    # OLD note: 54% table width above removes "Overfull \hbox (1.65279pt too wide)"
+    #                 and "Underfull \hbox (badness 10000)"
+    # OLD: \begin{tabular}[t]{|C{15pt}|rr|rR{18pt}rR{18pt}r|}
+
+    # note: table may have different widths due to the 1st column (e.g. Fri versus Wed)
+    # note: table may have different widths due to the 'v' column (e.g. 6.9' versus 15.3')
+    # note: table may have different widths due to the 'd' column (e.g. -8.2' versus -13.9')
+
     tab = r'''\noindent
-\begin{tabular*}{0.54\textwidth}[t]{@{\extracolsep{\fill}}|c|rr|rrrrr|}
+\setlength{\tabcolsep}{5.8pt}  % default 6pt
+\begin{tabular}[t]{|c|rr|rrrrr|}
 \multicolumn{1}{c}{\normalsize{h}}& \multicolumn{2}{c}{\normalsize{Sun}} & \multicolumn{5}{c}{\normalsize{Moon}}\\
 '''
-    # note: 54% table width above removes "Overfull \hbox (1.65279pt too wide)"
-    #                 and "Underfull \hbox (badness 10000)"
     n = 0
     while n < 3:
         da = date + n
@@ -375,16 +414,18 @@ def sunmoontab(date):
             # add space between tables...
             tab = tab + r'''\multicolumn{7}{c}{}\\[-1.5ex]'''
         n += 1
-    tab = tab + r'''\end{tabular*}'''
+    tab = tab + r'''\end{tabular}
+'''
     return tab
 
 
 def sunmoontabm(date):
     # generates LaTeX table for sun and moon (modern style)
+
     tab = r'''\noindent
 \renewcommand{\arraystretch}{1.1}
-\setlength{\tabcolsep}{4pt}
-\quad\quad
+\setlength{\tabcolsep}{4pt}  % default 6pt
+\quad
 \begin{tabular}[t]{crrcrrrrr}
 \multicolumn{1}{c}{\normalsize{h}} & 
 \multicolumn{2}{c}{\normalsize{Sun}} & &
@@ -471,8 +512,8 @@ def sunmoontabm(date):
             # add space between tables...
             tab = tab + r'''\multicolumn{{7}}{{c}}{{}}\\{}'''.format(vsep)
         n += 1
-    tab = tab + r'''\end{tabular}
-\quad\quad'''
+    tab = tab + r'''\end{tabular}\quad\quad
+'''
     return tab
 
 
@@ -577,15 +618,15 @@ def twilighttab(date):
 # Twilight tables ...........................................
     #lat = [72,70,68,66,64,62,60,58,56,54,52,50,45,40,35,30,20,10,0, -10,-20,-30,-35,-40,-45,-50,-52,-54,-56,-58,-60]
     latNS = [72, 70, 58, 40, 10, -10, -50, -60]
-    tab = r'''
-\begin{tabular*}{0.45\textwidth}[t]{@{\extracolsep{\fill}}|r|ccc|ccc|}
-\multicolumn{7}{c}{\normalsize{}}\\
-'''
+    # OLD: \begin{tabular*}{0.45\textwidth}[t]{@{\extracolsep{\fill}}|r|ccc|ccc|}
 
     if config.tbls == "m":
     # The header begins with a thin empty row as top padding; and the top row with
     # bold text has some padding below it. This result gives a balanced impression.
-        tab = tab + r'''\hline
+        tab = r'''\setlength{\tabcolsep}{5pt}  % default 6pt
+\begin{tabular}[t]{|r|ccc|ccc|}
+\multicolumn{7}{c}{\normalsize{}}\\
+\hline
 \multicolumn{1}{|c|}{} & & & \multicolumn{1}{|c|}{} & \multicolumn{1}{c|}{} & & \multicolumn{1}{c|}{}\\[-2.0ex]
 \multicolumn{1}{|c|}{\multirow{2}{*}{\textbf{Lat.}}} & 
 \multicolumn{2}{c}{\footnotesize{\textbf{Twilight}}} & 
@@ -602,7 +643,10 @@ def twilighttab(date):
 \hline\rule{0pt}{2.6ex}\noindent
 '''
     else:
-        tab = tab + r'''\hline
+        tab = r'''\setlength{\tabcolsep}{5.8pt}  % default 6pt
+\begin{tabular}[t]{|r|ccc|ccc|}
+\multicolumn{7}{c}{\normalsize{}}\\
+\hline
 \multicolumn{1}{|c|}{\rule{0pt}{2.4ex}\multirow{2}{*}{\textbf{Lat.}}} & 
 \multicolumn{2}{c}{\textbf{Twilight}} & 
 \multicolumn{1}{|c|}{\multirow{2}{*}{\textbf{Sunrise}}} & 
@@ -694,20 +738,25 @@ def twilighttab(date):
         else:
 # print a row with two moonrise/moonset events on the same day & latitude
             tab = tab + r'''\multirow{{2}}{{*}}{{\textbf{{{}}} {}$^\circ$}}'''.format(hs,abs(i))
+            #cellcolor = r'''\cellcolor[gray]{0.9}'''
 # top row...
             for k in range(len(moon)):
                 if moon2[k] != '--:--':
-                    tab = tab + r''' & {}'''.format(moon[k])
+                    #tab = tab + r''' & {}'''.format(cellcolor + moon[k])
+                    tab = tab + r''' & \colorbox{{khaki!45}}{{{}}}'''.format(moon[k])
                 else:
                     tab = tab + r''' & \multirow{{2}}{{*}}{{{}}}'''.format(moon[k])
-            tab = tab + r'''\\'''	# terminate top row
+            tab = tab + r'''\\
+'''	# terminate top row
 # bottom row...
             for k in range(len(moon)):
                 if moon2[k] != '--:--':
-                    tab = tab + r''' & {}'''.format(moon2[k])
+                    #tab = tab + r''' & {}'''.format(cellcolor + moon2[k])
+                    tab = tab + r''' & \colorbox{{khaki!45}}{{{}}}'''.format(moon2[k])
                 else:
                     tab = tab + r'''&'''
-            tab = tab + r'''\\'''	# terminate bottom row
+            tab = tab + r'''\\
+'''	# terminate bottom row
         j += 1
     # add space between tables...
     tab = tab + r'''\hline\multicolumn{7}{c}{}\\[-1.5ex]
@@ -749,7 +798,7 @@ def twilighttab(date):
             tab = tab + r'''{} & {} & {} & {} & {} & {} & {}({}\%) \\
 '''.format(d.datetime().strftime("%d"),eq[0],eq[1],eq[2],eq[3],eq[4],eq[5],eq[6])
     tab = tab + r'''\hline
-\end{tabular*}'''
+\end{tabular}'''
     return tab
 
 
@@ -768,7 +817,8 @@ def doublepage(date, page1):
     if not(page1):
         page = r'''
 % ------------------ N E W   P A G E ------------------
-\newpage'''
+\newpage
+\restoregeometry    % reset to even-page margins'''
 
     leftindent = ""
     rightindent = ""
@@ -782,9 +832,9 @@ def doublepage(date, page1):
 {}\textbf{{{}, {}, {}   ({}.,  {}.,  {}.)}}'''.format(leftindent,ephem.date(date).datetime().strftime("%B %d"),ephem.date(date+1).datetime().strftime("%d"),ephem.date(date+2).datetime().strftime("%d"),ephem.date(date).datetime().strftime("%a"),ephem.date(date+1).datetime().strftime("%a"),ephem.date(date+2).datetime().strftime("%a"))
 
     if config.tbls == "m":
-        page = page + r'\par'
+        page = page + r'\\[1.0ex]'  # \par leaves about 1.2ex
     else:
-        page = page + r'\\[1.0ex]'
+        page = page + r'\\[0.7ex]'
 
     page = page + r'''
 \begin{scriptsize}
@@ -793,28 +843,30 @@ def doublepage(date, page1):
     if config.tbls == "m":
         page = page + planetstabm(date)
     else:
-        page = page + planetstab(date)
+        page = page + planetstab(date) + r'''\enskip
+'''
     page = page + starstab(date)
     str1 = r'''
-
 \end{{scriptsize}}
 % ------------------ N E W   P A G E ------------------
 \newpage
+\newgeometry{{nomarginpar, top={}, bottom={}, left={}, right={}}}
 \begin{{flushright}}
 \textbf{{{} to {}}}{}%
 \end{{flushright}}\par
 \begin{{scriptsize}}
-'''.format(ephem.date(date).datetime().strftime("%Y %B %d"),ephem.date(date+2).datetime().strftime("%b. %d"),rightindent)
+'''.format(tm, bm, oddim, oddom, ephem.date(date).datetime().strftime("%Y %B %d"), ephem.date(date+2).datetime().strftime("%b. %d"), rightindent)
     page = page + str1
     if config.tbls == "m":
         page = page + sunmoontabm(date)
     else:
-        page = page + sunmoontab(date)
+        page = page + sunmoontab(date) + r'''\enskip
+'''
     page = page + twilighttab(date)
+    # to avoid "Overfull \hbox" messages, leave a paragraph end before the end of a size change. (This may only apply to tabular* table style) See lines below...
     page = page + r'''
 
 \end{scriptsize}'''
-    # to avoid "Overfull \hbox" messages, always leave a paragraph end before the end of a size change. (See lines above)
     return page
 
 
@@ -830,13 +882,15 @@ def pages(date, p):
 
 
 def almanac(first_day, pagenum, dfA4):
-    # make almanac from date till date
+    # make almanac starting from first_day
+    global tm, bm, oddim, oddom
     year = first_day.year
     mth = first_day.month
     day = first_day.day
 
     # page size specific parameters
     if config.pgsz == "A4":
+        # pay attention to the limited page width
         paper = "a4paper"
         vsep1 = "2.0cm"
         vsep2 = "1.5cm"
@@ -846,14 +900,21 @@ def almanac(first_day, pagenum, dfA4):
         rm1 = "10mm"
         tm = "21mm"     # data pages...
         bm = "18mm"
-        lm = "10mm"
-        rm = "9mm"
+        # even data pages...
+        im = "10mm"     # inner margin (right side on even pages)
+        om = "9mm"      # outer margin (left side on even pages)
+        # odd data pages...
+        oddim = "14mm"  # inner margin (left side on odd pages)
+        oddom = "11mm"  # outer margin (right side on odd pages)
         if config.tbls == "m":
             tm = "10mm"
             bm = "15mm"
-            lm = "10mm"
-            rm = "10mm"
+            im = "10mm"
+            om = "10mm"
+            oddim = "14mm"
+            oddom = "11mm"
     else:
+        # pay attention to the limited page height
         paper = "letterpaper"
         vsep1 = "1.5cm"
         vsep2 = "1.0cm"
@@ -863,16 +924,21 @@ def almanac(first_day, pagenum, dfA4):
         rm1 = "12mm"
         tm = "12.2mm"   # data pages...
         bm = "13mm"
-        lm = "15mm"
-        rm = "11mm"
+        # even data pages...
+        im = "13mm"     # inner margin (right side on even pages)
+        om = "13mm"     # outer margin (left side on even pages)
+        # odd data pages...
+        oddim = "14mm"  # inner margin (left side on odd pages)
+        oddom = "11mm"  # outer margin (right side on odd pages)
         if config.tbls == "m":
             tm = "4mm"
-            bm = "10mm"
-            lm = "13mm"
-            rm = "13mm"
+            bm = "8mm"
+            im = "13mm"
+            om = "13mm"
+            oddim = "14mm"
+            oddom = "14mm"
 
-    alm = r'''\documentclass[10pt, twoside, {}]{{report}}
-'''.format(paper)
+    alm = r'''\documentclass[10pt, twoside, {}]{{report}}'''.format(paper)
 
     alm = alm + r'''
 %\usepackage[utf8]{inputenc}
@@ -881,16 +947,21 @@ def almanac(first_day, pagenum, dfA4):
 
     # to troubleshoot add "showframe, verbose," below:
     alm = alm + r'''
-\usepackage[nomarginpar, top={}, bottom={}, left={}, right={}]{{geometry}}'''.format(tm,bm,lm,rm)
+\usepackage[nomarginpar, top={}, bottom={}, left={}, right={}]{{geometry}}'''.format(tm,bm,im,om)
 
     if config.tbls == "m":
         alm = alm + r'''
 \usepackage[table]{xcolor}
+% [table] option loads the colortbl package for coloring rows, columns, and cells within tables.
 \definecolor{LightCyan}{rgb}{0.88,1,1}
 \usepackage{booktabs}'''
+    else:
+        alm = alm + r'''
+\usepackage{xcolor}  % highlight double moon events on same day'''
 
     # Note: \DeclareUnicodeCharacter is not compatible with some versions of pdflatex
     alm = alm + r'''
+\definecolor{khaki}{rgb}{0.76, 0.69, 0.57}
 \usepackage{multirow}
 \newcommand{\HRule}{\rule{\linewidth}{0.5mm}}
 \setlength{\footskip}{15pt}
@@ -910,7 +981,7 @@ def almanac(first_day, pagenum, dfA4):
     alm = alm + r'''
     \begin{{titlepage}}
     \begin{{center}}
-    \textsc{{\Large Generated by PyAlmanac}}\\[0.7cm]
+    \textsc{{\Large Generated using Ephem}}\\[0.7cm]
     % TRIM values: left bottom right top
     \includegraphics[clip, trim=5mm 8cm 5mm 21mm, width=0.8\textwidth]{{{}}}\\'''.format(dfA4)
 
@@ -947,7 +1018,7 @@ def almanac(first_day, pagenum, dfA4):
     \end{center}
     \begin{description}\footnotesize
     \item[Disclaimer:] These are computer generated tables - use them at your own risk.
-    The accuracy has been randomly checked with JPL HORIZONS System, but cannot be guaranteed.
+    The accuracy has been checked as well as possible, but cannot be guaranteed.
     This means I cannot be held liable if you get lost on the oceans because of errors in this publication.
     Besides, this publication only contains the 'daily pages' of the Nautical Almanac: an official version of the Nautical Almanac is indispensable.
     \end{description}
